"use strict";

import Emel from 'emel';

import forkawesome_emel from './forkawesome_emel.mjs';

import tabledefs from  './tabledefs/index.mjs';

class GlobalUI {
	constructor() {
		this.emel = new Emel().emel;
	}
	
	async init() {
		const status = await globalThis.sysquery.status();
		
		// 1: Update version display
		el_version.replaceChildren(
			document.createTextNode(status.version)
		);
		
		// 2: Update navigation bar
		const el_navitems = document.querySelector(".nav-items"); // <ul>
		
		// Strip all non-static navigation items
		for(let item of el_navitems.children) {
			if(item.classList.contains("static")) continue;
			el_navitems.removeChild(item);
		}
		
		// Generate new dynamic navigation items
		const result = document.createDocumentFragment();
		for(const table_name of status.tables) {
			result.append(...this.emel(`li>a[href=#table/?]>${forkawesome_emel(tabledefs[table_name].icon)}+{?}`, {
				placeholders: [ table_name, table_name ]
			}));
		}
		
		el_navitems.prepend(result);
	}
}

export default GlobalUI;
